@@ -51,6 +51,11 @@ class DriverCommands:
     def get_source(cls, driver):
         return driver.page_source
 
+    @classmethod
+    def send_keys(cls, driver, key_str):
+        print(key_str)
+        ActionChains(driver).send_keys(key_str).perform()
+
     @classmethod
     def is_web_alert_present(cls, driver):
         from selenium.webdriver.support.ui import WebDriverWait
